"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startServer = void 0;
const tslib_1 = require("tslib");
const http_status_codes_1 = require("http-status-codes");
const express_1 = require("express");
const pino_1 = (0, tslib_1.__importDefault)(require("pino"));
const middleware_1 = require("./middleware");
const models_1 = require("./models");
const routes_1 = require("./routes");
const express = require("express");
const pkg = require(`${getPkgJsonDir()}/package.json`);
const logger = (0, pino_1.default)();
const app = express();
app.set("trust proxy", true);
if (process.env.NODE_ENV !== "production") {
    app.use("*", (req, res, next) => {
        logger.trace({ method: req.method, path: req.path, params: req.params });
        next();
    });
}
const versionString = `Nandu NPM Registry v${pkg.version}`;
app.get("/", (req, res) => {
    res.status(200).send(versionString);
});
app.get("/-/ping", (req, res) => {
    res.status(200).send(versionString);
});
app.use(routes_1.loginRouter);
app.use((0, middleware_1.authToken)());
app.use(routes_1.packagesRouter);
app.use(routes_1.userRouter);
app.use(routes_1.tokensRouter);
app.use(routes_1.orgsRouter);
app.use(routes_1.teamsRouter);
app.use("*", (0, express_1.json)(), (req, res, next) => {
    logger.info({
        method: req.method,
        path: req.path,
        params: req.params,
        headers: req.headers,
        body: req.body,
    }, "Unhandled route");
    // Npm cli does not react to 501 (Not implemented) status code
    res.status(http_status_codes_1.StatusCodes.NOT_FOUND).end("Not implemented");
});
// Application error logging.
app.on("error", logger.error);
async function startServer(port = 4567) {
    app.listen(port, () => {
        console.log(`Nandu is running on port ${port}.`);
    });
    await (0, models_1.initDb)();
}
exports.startServer = startServer;
// Source: https://stackoverflow.com/questions/10265798/determine-project-root-from-a-running-node-js-application
function getPkgJsonDir() {
    const { dirname } = require("path");
    const { constants, accessSync } = require("fs");
    for (let path of module.paths) {
        try {
            let prospectivePkgJsonDir = dirname(path);
            accessSync(path, constants.F_OK);
            return prospectivePkgJsonDir;
        }
        catch (e) { }
    }
}
//# sourceMappingURL=index.js.map