"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initDb = exports.db = void 0;
const tslib_1 = require("tslib");
const sequelize_1 = require("sequelize");
const pino_1 = (0, tslib_1.__importDefault)(require("pino"));
const config_1 = (0, tslib_1.__importDefault)(require("../../config"));
const logger = (0, pino_1.default)({ name: "Sequelize", level: config_1.default.logLevel });
exports.db = new sequelize_1.Sequelize(config_1.default.sequelize.uri, {
    logging: (msg) => logger.debug(msg),
});
const initDb = async () => {
    try {
        await exports.db.authenticate();
        logger.debug("Connection has been established successfully.");
        await exports.db.sync();
        logger.debug("Synced models");
        /**
         * Add root user if needed.
         */
        const { User } = await Promise.resolve().then(() => (0, tslib_1.__importStar)(require("../models/user")));
        await User.addRootUser();
    }
    catch (error) {
        logger.error(error, "Unable to connect to the database");
    }
};
exports.initDb = initDb;
//# sourceMappingURL=db.js.map