"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Organization = exports.UserOrganization = void 0;
const sequelize_1 = require("sequelize");
const db_1 = require("./db");
const user_1 = require("./user");
const enums_1 = require("../enums");
const roleActions = {
    owner: new Set(Object.values(enums_1.OrganizationAction)),
    admin: new Set([
        enums_1.OrganizationAction.createTeam,
        enums_1.OrganizationAction.listTeams,
        enums_1.OrganizationAction.listTeamMembers,
        enums_1.OrganizationAction.deleteTeam,
        enums_1.OrganizationAction.addMemberToTeam,
        enums_1.OrganizationAction.removeMemberFromTeam,
        enums_1.OrganizationAction.manageTeamPackageAccess,
        enums_1.OrganizationAction.publishPackage,
    ]),
    developer: new Set([enums_1.OrganizationAction.publishPackage]),
};
/**
 * Organization's membership
 */
exports.UserOrganization = db_1.db.define("UserOrganization", {
    role: sequelize_1.DataTypes.ENUM("owner", "admin", "developer"),
}, { timestamps: false });
/**
 * Model Organization (aka scope)
 *
 */
class Organization extends sequelize_1.Model {
    static checkPermissions(role, ...actions) {
        return actions.every((action) => roleActions[role].has(action));
    }
    static async getMemberRole(organizationId, userId, transaction) {
        const membership = await exports.UserOrganization.findOne({
            where: {
                organizationId,
                userId,
            },
            transaction,
        });
        if (membership) {
            return membership.getDataValue("role");
        }
    }
}
exports.Organization = Organization;
Organization.init({
    name: {
        type: sequelize_1.DataTypes.STRING,
        primaryKey: true,
    },
}, {
    sequelize: db_1.db,
    modelName: "Organization",
});
user_1.User.belongsToMany(Organization, {
    through: exports.UserOrganization,
    foreignKey: "userId",
});
Organization.belongsToMany(user_1.User, {
    through: exports.UserOrganization,
    foreignKey: "organizationId",
});
//# sourceMappingURL=organization.js.map