"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.User = void 0;
const tslib_1 = require("tslib");
const sequelize_1 = require("sequelize");
const bcrypt = (0, tslib_1.__importStar)(require("bcrypt"));
const pino_1 = (0, tslib_1.__importDefault)(require("pino"));
const config_1 = (0, tslib_1.__importDefault)(require("../../config"));
const db_1 = require("./db");
const logger = (0, pino_1.default)();
class User extends sequelize_1.Model {
    static hashPassword(token) {
        return bcrypt.hashSync(token, config_1.default.saltRounds);
    }
    /**
     * Add the root user if there is no root user.
     */
    static async addRootUser() {
        const transaction = await db_1.db.transaction();
        try {
            const userId = `org.couchdb.user:${config_1.default.root.user}`;
            const rootUser = await User.findOne({
                where: {
                    _id: userId,
                },
                transaction,
            });
            if (!rootUser) {
                logger.info("Root user missing so adding one now");
                await User.create({
                    _id: userId,
                    name: config_1.default.root.user,
                    password: config_1.default.root.password,
                    type: "root",
                }, { transaction });
            }
            await transaction.commit();
        }
        catch (err) {
            logger.error(err);
            await transaction.rollback();
            throw err;
        }
    }
    checkPassword(password) {
        return bcrypt.compareSync(password, this.getDataValue("password"));
    }
}
exports.User = User;
User.init({
    _id: {
        type: sequelize_1.DataTypes.STRING,
        allowNull: false,
        primaryKey: true,
    },
    type: sequelize_1.DataTypes.STRING,
    name: {
        type: sequelize_1.DataTypes.STRING,
        unique: true,
    },
    email: sequelize_1.DataTypes.STRING,
    password: {
        type: sequelize_1.DataTypes.STRING,
        set(password) {
            if (password) {
                this.setDataValue("password", User.hashPassword(password));
            }
        },
    },
}, {
    sequelize: db_1.db,
    modelName: "User",
});
//# sourceMappingURL=user.js.map