"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Version = void 0;
const sequelize_1 = require("sequelize");
const db_1 = require("./db");
const author_1 = require("./author");
const dist_tag_1 = require("../models/dist-tag");
const storage_1 = require("../storage");
class Version extends sequelize_1.Model {
    static addVersions(storage, packageId, versions, attachments, tarballPrefix, tagName) {
        return Promise.all(Object.keys(versions).map(async (ver) => {
            const version = versions[ver];
            const versionFile = `${version.name}-${version.version}.tgz`;
            const attachment = attachments[versionFile];
            const { shasum, integrity } = await (0, storage_1.uploadAttachment)(storage, versionFile, attachment);
            await Version.create(Object.assign(Object.assign({}, version), { packageId, dist: {
                    shasum,
                    integrity,
                    tarball: `${tarballPrefix}${versionFile}`,
                } }));
            await dist_tag_1.DistTag.upsert({
                key: `${packageId}-${tagName}`,
                name: tagName,
                version: version.version,
                packageId,
            });
        }));
    }
}
exports.Version = Version;
Version.init({
    _id: {
        type: sequelize_1.DataTypes.STRING,
        allowNull: false,
        primaryKey: true,
    },
    name: {
        type: sequelize_1.DataTypes.STRING,
        allowNull: false,
    },
    readme: {
        type: sequelize_1.DataTypes.TEXT,
    },
    version: {
        type: sequelize_1.DataTypes.STRING,
        allowNull: false,
    },
    description: sequelize_1.DataTypes.STRING,
    repository: sequelize_1.DataTypes.JSON,
    keywords: sequelize_1.DataTypes.STRING,
    author: sequelize_1.DataTypes.JSON,
    maintainers: sequelize_1.DataTypes.JSON,
    devDependencies: sequelize_1.DataTypes.JSON,
    dependencies: sequelize_1.DataTypes.JSON,
    dist: sequelize_1.DataTypes.JSON,
    license: sequelize_1.DataTypes.STRING,
}, {
    sequelize: db_1.db,
    modelName: "Version",
    // Other model options go here
});
Version.belongsTo(author_1.Author, { foreignKey: "authorId" });
// Version.belongsTo(Package, { foreignKey: "packageId" });
/*
export class Version {
    _id: string;
    name: string;
    version: string;
    description: string;
    main: string;
    scripts: string;
    repository: {
        type: string;
        url: string;
    };
    files: string;
    keywords: string[];
    author: {
        name: string;
        email: string;
        url: string;
    },
    license: string;
    bugs: string;
    homepage: string;
    devDependencies: object;
    dependencies: object;
    dist: {
        shasum: string;
        tarball: string; // "https://registry.npmjs.org/koa-bodyparser/-/koa-bodyparser-0.0.1.tgz"
    },
    _from: string;
    _npmVersion: string;
    _npmUser: { "name": string, "email": string };
    maintainers: [{ "name": "dead_horse", "email": "dead_horse@qq.com" }];
    directories: {};
}
*/
//# sourceMappingURL=version.js.map