"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.router = void 0;
/**
 *
 */
const http_status_codes_1 = require("http-status-codes");
const express_1 = require("express");
const middleware_1 = require("../middleware");
const team_1 = require("../models/team");
const enums_1 = require("../enums");
exports.router = (0, express_1.Router)();
/**
 * Remove a team from organization
 */
exports.router.delete("/-/team/:scope/:team", (0, middleware_1.canWrite)(), (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.deleteTeam), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { scope, team } = req.params;
    await team_1.Team.removeTeam(scope, team);
    res.status(http_status_codes_1.StatusCodes.OK).json({});
}));
/**
 * Get users belonging to a given team
 */
exports.router.get("/-/team/:scope/:teamName/user", (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.listTeamMembers), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { scope, teamName } = req.params;
    const team = await team_1.Team.getMembers(scope, teamName);
    res
        .status(http_status_codes_1.StatusCodes.OK)
        .json(team.getDataValue("members").map((user) => user.name));
}));
/**
 * Add a user to a given team in a given organization.
 */
exports.router.put("/-/team/:scope/:team/user", (0, express_1.json)(), (0, middleware_1.canWrite)(), (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.addMemberToTeam), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { scope, team } = req.params;
    const { user: userName } = req.body;
    await team_1.Team.addUser(scope, team, userName);
    res.status(http_status_codes_1.StatusCodes.OK).json({});
}));
/**
 * Remove a user from  a given team
 */
exports.router.delete("/-/team/:scope/:team/user", (0, express_1.json)(), (0, middleware_1.canWrite)(), (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.removeMemberFromTeam), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { scope, team } = req.params;
    const { user: userName } = req.body;
    await team_1.Team.removeUser(scope, team, userName);
    res.status(http_status_codes_1.StatusCodes.OK).json({});
}));
/**
 * List package access for a given team in a given organization
 */
exports.router.get("/-/team/:scope/:team/package", (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.manageTeamPackageAccess), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { scope, team } = req.params;
    const packages = await team_1.Team.listPackages(scope, team);
    res.status(http_status_codes_1.StatusCodes.OK).json({ packages });
}));
/**
 * Grant access to team
 */
exports.router.put("/-/team/:scope/:team/package", (0, express_1.json)(), (0, middleware_1.canWrite)(), (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.manageTeamPackageAccess), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { scope, team } = req.params;
    const { package: pkg, permissions } = req.body;
    await team_1.Team.grantAccess(scope, team, pkg, permissions);
    res.status(http_status_codes_1.StatusCodes.OK).json({});
}));
/**
 * Revoke access from team
 */
exports.router.delete("/-/team/:scope/:team/package", (0, express_1.json)(), (0, middleware_1.canWrite)(), (0, middleware_1.canAccessOrganization)(enums_1.OrganizationAction.manageTeamPackageAccess), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { scope, team } = req.params;
    const { package: pkg } = req.body;
    await team_1.Team.revokeAccess(scope, team, pkg);
    res.status(http_status_codes_1.StatusCodes.OK).json({});
}));
//# sourceMappingURL=teams.js.map