"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.router = void 0;
/**
 *
 */
const http_status_codes_1 = require("http-status-codes");
const express_1 = require("express");
const middleware_1 = require("../middleware");
const utils_1 = require("../utils");
const models_1 = require("../models");
exports.router = (0, express_1.Router)();
/**
 * Get list of tokens.
 */
exports.router.get("/-/npm/v1/tokens/:userId?", (0, middleware_1.asyncWrap)(async (req, res) => {
    const { _id: userId } = res.locals.user;
    const targetUserId = req.params.userId || userId;
    if (userId && userId !== targetUserId && !(0, utils_1.isRoot)(res.locals.user)) {
        // Only roots can list other users tokens.
        res.status(http_status_codes_1.StatusCodes.FORBIDDEN).end("Missing rights to list tokens");
    }
    // TODO: Implement pagination
    const result = await models_1.Token.getTokens(res.locals.user._id);
    res.json(result);
}));
/**
 * Create a new token
 */
exports.router.post("/-/npm/v1/tokens/:userId?", (0, express_1.json)(), (0, middleware_1.canWrite)(), (0, middleware_1.authPassword)(), (0, middleware_1.asyncWrap)(async (req, res) => {
    var _a;
    const { _id: userId } = res.locals.user;
    const targetUserId = req.params.userId || userId;
    const { readonly, cidr_whitelist: cidrWhitelist } = req.body;
    if (cidrWhitelist && !Array.isArray(cidrWhitelist)) {
        return res
            .status(http_status_codes_1.StatusCodes.NOT_ACCEPTABLE)
            .end("cidr-whitelist must be an array");
    }
    if (userId && userId !== targetUserId && !(0, utils_1.isRoot)(res.locals.user)) {
        // Only roots can create tokens on behalf of other users
        return res
            .status(http_status_codes_1.StatusCodes.FORBIDDEN)
            .end("Missing rights to create token");
    }
    const [uuid, token] = await models_1.Token.createTokenForUser(targetUserId, {
        readonly,
        cidrWhitelist,
    });
    res.status(http_status_codes_1.StatusCodes.CREATED).send({
        key: token.getDataValue("key"),
        token: uuid,
        cidr_whitelist: token.getDataValue("cidrWhitelist"),
        readonly: (_a = token.getDataValue("access")) === null || _a === void 0 ? void 0 : _a.includes("readonly"),
        created: token.getDataValue("createdAt"),
    });
}));
/*
 * Delete a given token
 */
exports.router.delete("/-/npm/v1/tokens/token/:tokenOrKey", (0, middleware_1.canWrite)(), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { tokenOrKey } = req.params;
    const { _id: userId } = res.locals.user;
    const hasRevoked = await models_1.Token.revokeToken(userId, tokenOrKey, (0, utils_1.isRoot)(res.locals.user));
    if (!hasRevoked) {
        res.status(http_status_codes_1.StatusCodes.NOT_FOUND).end();
    }
    else {
        res.end();
    }
}));
//# sourceMappingURL=tokens.js.map