"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.router = void 0;
const tslib_1 = require("tslib");
/**
 *
 */
const http_status_codes_1 = require("http-status-codes");
const express_1 = require("express");
const user_1 = require("../models/user");
const models_1 = require("../models");
const middleware_1 = require("../middleware");
const utils_1 = require("../utils");
exports.router = (0, express_1.Router)();
/*
{
    "ok": false,
    "message": "Unknown error while authenticating"
}
*/
/**
 * Update or add a new User
 *
 */
exports.router.put("/-/user/:userId", (0, express_1.json)(), (0, middleware_1.canWrite)(), (0, middleware_1.asyncWrap)(async (req, res) => {
    // Currently we do not use the scope, left here for reference.
    const { "npm-scope": scope } = req.headers;
    const { name, password, email, type } = req.body;
    const { user } = res.locals;
    const { _id: userId } = res.locals.user;
    const targetUserId = req.params.userId;
    const data = {
        name,
        email,
        password,
        type,
    };
    if (userId === targetUserId) {
        if (!user.checkPassword(password)) {
            res.status(http_status_codes_1.StatusCodes.UNAUTHORIZED).json({
                error: "Invalid password",
            });
        }
        else {
            user_1.User.update({
                name,
                email,
                password,
                type,
            }, {
                where: {
                    _id: userId,
                },
            });
        }
        res.status(http_status_codes_1.StatusCodes.OK).json({});
    }
    else if ((0, utils_1.isRoot)(res.locals.user)) {
        const transaction = await models_1.db.transaction();
        try {
            const user = await user_1.User.findOne({
                where: { _id: targetUserId },
                transaction,
            });
            if (user) {
                res
                    .status(http_status_codes_1.StatusCodes.CONFLICT)
                    .json({ ok: false, message: "cannot create existing user" });
                throw new Error("Cannot create existing user");
            }
            await user_1.User.create(Object.assign({ _id: targetUserId }, data), { transaction });
            await transaction.commit();
        }
        catch (err) {
            await transaction.rollback();
            throw err;
        }
        res.status(http_status_codes_1.StatusCodes.CREATED).json({});
    }
    else {
        res.status(http_status_codes_1.StatusCodes.FORBIDDEN).json({
            error: "Missing rights",
        });
    }
}));
/**
 * Change password
 */
exports.router.post("/-/npm/v1/user", (0, express_1.json)(), (0, middleware_1.canWrite)(), (0, middleware_1.asyncWrap)(async (req, res) => {
    const { password } = req.body;
    const user = res.locals.user;
    if (user.checkPassword(password.old)) {
        await user_1.User.update({
            password: password.new,
        }, {
            where: { _id: user.getDataValue("_id") },
        });
        res.status(http_status_codes_1.StatusCodes.OK).json({});
    }
    else {
        res.status(http_status_codes_1.StatusCodes.NOT_ACCEPTABLE).end();
    }
}));
/**
 * Get own user data
 */
exports.router.get("/-/npm/v1/user", (0, middleware_1.asyncWrap)(async (req, res) => {
    const _a = res.locals.user, { _id, password } = _a, user = (0, tslib_1.__rest)(_a, ["_id", "password"]);
    res.json(user);
}));
/**
 * Get a different user's data
 */
exports.router.get("/-/npm/v1/user/:userId", (0, middleware_1.asyncWrap)(async (req, res) => {
    if ((0, utils_1.isRoot)(res.locals.user)) {
        const user = await user_1.User.findOne({ where: { _id: req.params.userId } });
        if (user) {
            res.json(user);
        }
        else {
            res.status(http_status_codes_1.StatusCodes.NOT_FOUND).end();
        }
    }
    else {
        res.status(http_status_codes_1.StatusCodes.FORBIDDEN).json({
            error: "Missing rights",
        });
    }
}));
/**
 * List all packages that this user has access to.
 */
exports.router.get("/-/user/:user/package", (0, middleware_1.asyncWrap)(async (req, res) => {
    const { user } = req.params;
    // TODO: Implement
    // We could list all the packages the user "owns", as well as all the packages
    // the teams the user is part of have access to?
    res.status(http_status_codes_1.StatusCodes.NOT_ACCEPTABLE).end();
}));
exports.router.get("/-/whoami", (0, middleware_1.asyncWrap)(async (req, res) => {
    res.json({ username: res.locals.user.name });
}));
//# sourceMappingURL=user.js.map