"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalStorage = void 0;
const tslib_1 = require("tslib");
const path = (0, tslib_1.__importStar)(require("path"));
const fs = (0, tslib_1.__importStar)(require("fs"));
class LocalStorage {
    constructor(dirName) {
        this.dirName = dirName;
        fs.mkdirSync(dirName, { recursive: true });
    }
    add(pathName, inputStream) {
        const fullPathName = path.join(this.dirName, pathName);
        fs.mkdirSync(path.dirname(fullPathName), { recursive: true });
        const outputStream = fs.createWriteStream(fullPathName, { flags: "wx" });
        inputStream.pipe(outputStream);
        return new Promise((resolve, reject) => {
            outputStream.on("finish", resolve);
            outputStream.on("error", reject);
        });
    }
    async get(pathName) {
        const fullPathName = path.join(this.dirName, pathName);
        return fs.createReadStream(fullPathName);
    }
    remove(pathName) {
        const fullPathName = path.join(this.dirName, pathName);
        return fs.promises.unlink(fullPathName);
    }
}
exports.LocalStorage = LocalStorage;
//# sourceMappingURL=local.storage.js.map