"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStorage = exports.downloadPackage = exports.uploadAttachment = void 0;
const tslib_1 = require("tslib");
const crypto_1 = require("crypto");
const stream_1 = require("stream");
const http_status_codes_1 = require("http-status-codes");
const config_1 = (0, tslib_1.__importDefault)(require("../../config"));
const index_1 = require("./index");
async function uploadAttachment(storage, versionFile, attachment) {
    const buffer = Buffer.from(attachment.data, "base64");
    await storage.add(versionFile, stream_1.Readable.from(buffer));
    const shasum = (0, crypto_1.createHash)("sha1").update(buffer).digest("hex");
    const integrity = `sha512-${(0, crypto_1.createHash)("sha512")
        .update(buffer)
        .digest("base64")}`;
    return { shasum, integrity };
}
exports.uploadAttachment = uploadAttachment;
async function downloadPackage(res, storage, versionFile) {
    const srcStream = await storage.get(versionFile);
    srcStream.on("error", (err) => {
        if (err["code"] == "ENOENT") {
            res.status(http_status_codes_1.StatusCodes.NOT_FOUND).end("file not found");
        }
        else {
            res.status(http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR);
        }
    });
    srcStream.pipe(res);
    res.on("error", (err) => {
        if (err["code"] == "ENOENT") {
            res.status(http_status_codes_1.StatusCodes.NOT_FOUND).end("file not found");
        }
        else {
            res.status(http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR);
        }
    });
}
exports.downloadPackage = downloadPackage;
function getStorage() {
    if (config_1.default.aws.s3.bucket) {
        return new index_1.S3Storage(config_1.default.aws.s3.bucket);
    }
    else {
        return new index_1.LocalStorage(config_1.default.local.baseDir);
    }
}
exports.getStorage = getStorage;
//# sourceMappingURL=util.js.map